##  Overview
Sync tags on fact sheets with their current lifecycle phases. For example, when applications enter the Active lifecycle phase, automatically add the tag "Active."
The automation is triggered by any changes to the Lifecycle field on applications. The script checks the current lifecycle phase and adds matching tags to the fact sheet.
To find the IDs of tags set up in your workspace, use the code helpers for tags in the script editor. You can access code helpers on the left side of the script editor overlay.
